==> haskell-managed-1.0.9-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 managed
version:              1.0.9
visibility:           public
id:                   managed-1.0.9-D57Q6tda4Oi5Cz7tXkGkaQ
key:                  managed-1.0.9-D57Q6tda4Oi5Cz7tXkGkaQ
license:              BSD-3-Clause
copyright:            2014 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.

    The reason this package defines a specialized version of these types is to:

    * be more beginner-friendly,

    * simplify inferred types and error messages, and:

    * provide some additional type class instances that would otherwise be orphan
    instances

category:             Control
abi:                  418d0390dac893e5b15269acbfb819e7
exposed:              True
exposed-modules:      Control.Monad.Managed Control.Monad.Managed.Safe
import-dirs:          /usr/lib/ghc-9.0.2/site-local/managed-1.0.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/managed-1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/managed-1.0.9
hs-libraries:         HSmanaged-1.0.9-D57Q6tda4Oi5Cz7tXkGkaQ
depends:              base-4.15.1.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html:         /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-managed-1.0.10-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-managed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 managed
version:              1.0.10
visibility:           public
id:                   managed-1.0.10-FbYe4HVaAYsd6rEVZIDXI
key:                  managed-1.0.10-FbYe4HVaAYsd6rEVZIDXI
license:              BSD-3-Clause
copyright:            2014 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A monad for managed values
description:
    In Haskell you very often acquire values using the @with...@
    idiom using functions of type @(a -> IO r) -> IO r@.  This idiom forms a
    @Monad@, which is a special case of the @ContT@ monad (from @transformers@) or
    the @Codensity@ monad (from @kan-extensions@).  The main purpose behind this
    package is to provide a restricted form of these monads specialized to this
    unusually common case.

    The reason this package defines a specialized version of these types is to:

    * be more beginner-friendly,

    * simplify inferred types and error messages, and:

    * provide some additional type class instances that would otherwise be orphan
    instances

category:             Control
abi:                  32dc146da9ba3db22bc4bf3975d5e5eb
exposed:              True
exposed-modules:      Control.Monad.Managed Control.Monad.Managed.Safe
import-dirs:          /usr/lib/ghc-9.0.2/site-local/managed-1.0.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/managed-1.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-managed
hs-libraries:         HSmanaged-1.0.10-FbYe4HVaAYsd6rEVZIDXI
depends:              base-4.15.1.0 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-managed/html/managed.haddock
haddock-html:         /usr/share/doc/haskell-managed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
